@@ -165,7 +165,11 @@ xfprintsettings_defaults(void)
 	settings->sheets.fillcols = TRUE;
 	settings->sheets.cols = 1;
 	settings->sheets.rows = 1;
+#ifdef DEFAULT_LETTER
+	settings->sheets.papersize = "Letter";
+#else
 	settings->sheets.papersize = "A4dj";
+#endif
 	settings->sheets.borders = FALSE;
 	settings->sheets.reverse = FALSE;
 	settings->vpages.linenumbers = 0;
